﻿using Pleiades;
using System;
using System.Drawing;
using System.Drawing.Printing;
using System.Windows.Forms;

namespace LissajousCurve
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();
		}

		private void panel1_Paint(object sender, PaintEventArgs e)
		{
			PlotMain(panel1.CreateGraphics(), panel1.ClientSize);
		}

		public void PlotMain(Graphics g, Size s)
		{
			Pleiades.GraphLibrary gl = new Pleiades.GraphLibrary();

			gl.PlotBEGIN(g, s);

			gl.Clear();
			gl.AxisInitialize(-1.5, -1.5, 1.5, 1.5);

			gl.AxisX(-1.0, 1.0, 0.1);
			gl.AxisY(-1.0, 1.0, 0.1);

			Plot_Lissajous(gl);

			gl.PlotEND();
		}

		private void Plot_Lissajous(GraphLibrary gl)
		{
			double deg2rad = Math.PI / 180;
			double a = int.Parse(textBox1.Text);
			double b = int.Parse(textBox2.Text);
			double c = int.Parse(textBox3.Text);

			gl.SetPenColor(Color.Black);
			gl.SetPenWidth(3);

			gl.PenUp();
			for (int i = 0; i <= 360; i++)
			{
				if (i != 0)
					gl.PenDown();
				double x = Math.Sin(a * i * deg2rad + c * deg2rad);
				double y = Math.Sin(b * i * deg2rad);
				gl.Move(x, y);
			}

			gl.DrawString(1.2, 1.4, 12, "X = sin(αθ + γ)");
			gl.DrawString(1.2, 1.2, 12, "Y = sin(βθ)");
			gl.DrawString(1.2, 1.0, 12, "α : " + a.ToString());
			gl.DrawString(1.2, 0.8, 12, "β : " + b.ToString());
			gl.DrawString(1.2, 0.6, 12, "γ : " + c.ToString());
		}

		private void Form1_Load(object sender, EventArgs e)
		{
			// 最小値、最大値を設定
			trackBar1.Minimum = 1;
			trackBar1.Maximum = 10;

			// 初期値を設定
			trackBar1.Value = 5;

			// 描画される目盛りの刻みを設定
			trackBar1.TickFrequency = 1;

			// スライダーをキーボードやマウス、
			// PageUp,Downキーで動かした場合の移動量設定
			trackBar1.SmallChange = 1;
			trackBar1.LargeChange = 1;

			// 値が変更された際のイベントハンドラーを追加
			trackBar1.ValueChanged += new EventHandler(trackBar1_ValueChanged);

			// 最小値、最大値を設定
			trackBar2.Minimum = 1;
			trackBar2.Maximum = 10;

			// 初期値を設定
			trackBar2.Value = 6;

			// 描画される目盛りの刻みを設定
			trackBar2.TickFrequency = 1;

			// スライダーをキーボードやマウス、
			// PageUp,Downキーで動かした場合の移動量設定
			trackBar2.SmallChange = 1;
			trackBar2.LargeChange = 1;

			// 値が変更された際のイベントハンドラーを追加
			trackBar2.ValueChanged += new EventHandler(trackBar2_ValueChanged);

			// 最小値、最大値を設定
			trackBar3.Minimum = 0;
			trackBar3.Maximum = 360;

			// 初期値を設定
			trackBar3.Value = 135;

			// 描画される目盛りの刻みを設定
			trackBar3.TickFrequency = 45;

			// スライダーをキーボードやマウス、
			// PageUp,Downキーで動かした場合の移動量設定
			trackBar3.SmallChange = 10;
			trackBar3.LargeChange = 10;

			// 値が変更された際のイベントハンドラーを追加
			trackBar3.ValueChanged += new EventHandler(trackBar3_ValueChanged);
		}

		void trackBar1_ValueChanged(object sender, EventArgs e)
		{
			// TrackBarの値が変更されたらテキストボックスに表示
			textBox1.Text = trackBar1.Value.ToString();
		}

		private void trackBar2_ValueChanged(object sender, EventArgs e)
		{
			// TrackBarの値が変更されたらテキストボックスに表示
			textBox2.Text = trackBar2.Value.ToString();
		}

		private void trackBar3_ValueChanged(object sender, EventArgs e)
		{
			// TrackBarの値が変更されたらテキストボックスに表示
			textBox3.Text = trackBar3.Value.ToString();
		}

		private void textBox1_TextChanged(object sender, EventArgs e)
		{
			if (textBox1.Text == "")
				textBox1.Text = "1";
			int num = int.Parse(textBox1.Text);
			if (num < 1) num = 1;
			if (num > 10) num = 10;
			textBox1.Text = num.ToString();
			trackBar1.Value = int.Parse(textBox1.Text);
			PlotMain(panel1.CreateGraphics(), panel1.ClientSize);
		}

		private void textBox2_TextChanged(object sender, EventArgs e)
		{
			if (textBox2.Text == "")
				textBox2.Text = "1";
			int num = int.Parse(textBox2.Text);
			if (num < 1) num = 1;
			if (num > 10) num = 10;
			textBox2.Text = num.ToString();
			trackBar2.Value = int.Parse(textBox2.Text);
			PlotMain(panel1.CreateGraphics(), panel1.ClientSize);
		}

		private void textBox3_TextChanged(object sender, EventArgs e)
		{
			if (textBox3.Text == "")
				textBox3.Text = "0";
			int num = int.Parse(textBox3.Text);
			if (num < 0) num = 0;
			if (num > 360) num = 360;
			textBox3.Text = num.ToString();
			trackBar3.Value = int.Parse(textBox3.Text);
			PlotMain(panel1.CreateGraphics(), panel1.ClientSize);
		}

		private void button1_Click(object sender, EventArgs e)
		{
			DoPrint(true);
		}

		private Size paparSize;
		private void DoPrint(bool mode)
		{
			PrintDocument pd = new System.Drawing.Printing.PrintDocument();

			var area = pd.DefaultPageSettings.PrintableArea;
			if (mode == true)
			{   // Landscape
				pd.DefaultPageSettings.Landscape = true;
				paparSize = new Size((int)area.Height, (int)area.Width);
			}
			else
			{   // Portrate
				pd.DefaultPageSettings.Landscape = false;
				paparSize = new Size((int)area.Width, (int)area.Height);
			}
			pd.PrintPage += new System.Drawing.Printing.PrintPageEventHandler(Pd_PrintPage);
			pd.Print();
		}

		private void Pd_PrintPage(object sender, System.Drawing.Printing.PrintPageEventArgs e)
		{
			PlotMain(e.Graphics, paparSize);
		}
	}
}
