﻿using Pleiades;
using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Drawing.Printing;
using System.Windows.Forms;

namespace DrawLine
{
	public partial class Form1 : Form
	{
		double deg2rad = Math.PI / 180.0;

		public Form1()
		{
			InitializeComponent();
		}

		private void Form1_Load(object sender, EventArgs e)
		{
			double A4Aspect = 297.0 / 210.0;
			this.ClientSize = new Size((int)(600 * A4Aspect), 600);
		}

		private void Form1_Paint(object sender, PaintEventArgs e)
		{
			int sw = 1;

			switch (sw)
			{
				case 1:
					PlotMain(this.CreateGraphics(), this.ClientSize);
					break;
				case 2:
					DoPrint(true);
					this.Close();
					break;
				case 3:
					//Bitmap img = new Bitmap(@"c:\picture.jpg");
					Bitmap img = new Bitmap(1000, 1000);
					PlotMain(Graphics.FromImage(img), img.Size);
					img.Save(@"test.bmp", System.Drawing.Imaging.ImageFormat.Bmp);
					img.Dispose();
					this.Close();
					break;
					//case 4:
					//	PlotMain(panel1.CreateGraphics(), panel1.ClientSize);
					//	break;
					//case 5:
					//	Bitmap canvas = new Bitmap(pictureBox1.Width, pictureBox1.Height);
					//	PlotMain(Graphics.FromImage(canvas), canvas.Size);
					//	pictureBox1.Image = canvas;
					//	break;
			}
		}

		private Size paparSize;
		private void DoPrint(bool mode)
		{
			PrintDocument pd = new System.Drawing.Printing.PrintDocument();

			var area = pd.DefaultPageSettings.PrintableArea;
			if (mode == true)
			{   // Landscape
				pd.DefaultPageSettings.Landscape = true;
				paparSize = new Size((int)area.Height, (int)area.Width);
			}
			else
			{   // Portrate
				pd.DefaultPageSettings.Landscape = false;
				paparSize = new Size((int)area.Width, (int)area.Height);
			}
			pd.PrintPage += new System.Drawing.Printing.PrintPageEventHandler(Pd_PrintPage);
			pd.Print();
		}

		private void Pd_PrintPage(object sender, System.Drawing.Printing.PrintPageEventArgs e)
		{
			PlotMain(e.Graphics, paparSize);
		}

		public void PlotMain(Graphics g, Size s)
		{
			Pleiades.GraphLibrary gl = new Pleiades.GraphLibrary();

			gl.PlotBEGIN(g, s);

			gl.Clear();

			gl.AxisInitialize(-11, -11, 11, 11);
			gl.AxisX(-10, 10, 1, 1);
			gl.AxisY(-10, 10, 1, 1);

			Plot_xy(gl);
			Plot_Rotate(gl);
			Plot_RotaryEngine(gl);
			Plot_Rotary34(gl);
			Plot_Lissajous(gl);
			Plot_Line(gl);
			Plot_Text(gl);
			Plot_Dot(gl);
			Plot_FillPath(gl);
			//Plot_Path(gl);
			Plot_DirectPath(gl);
			Plot_axis(gl);

			gl.PlotEND();

			System.Media.SystemSounds.Beep.Play();
		}

		//二次曲線
		private void Plot_xy(GraphLibrary gl)
		{
			gl.SetPenColor(Color.Black);
			gl.SetPenWidth(2);

			gl.PenUp();
			for (double x = -3; x <= 3; x += 0.01)
			{
				if (x != -3)
					gl.PenDown();
				double y = Math.Pow(x, 2);
				gl.Move(x, y);
			}
		}

		// 文字列の回転
		public void Plot_Rotate(GraphLibrary gl)
		{
			gl.DrawString(-5, 0, 0, "MS Pゴシック", 12, Color.Black, "ROTATE TEST", 0);
			gl.DrawString(-5, 0, 0, "MS Pゴシック", 12, Color.Green, "ROTATE TEST", 45);
			gl.DrawString(-5, 0, 0, "MS Pゴシック", 12, Color.Blue, "ROTATE TEST", 90);
			gl.DrawString(-5, 0, 0, "MS Pゴシック", 12, Color.Red, "ROTATE TEST", 135);
			gl.DrawString(-5, 0, 0, "MS Pゴシック", 12, Color.Black, "ROTATE TEST", 180);

		}

		// X軸及びY軸
		public void Plot_axis(GraphLibrary gl)
		{
			gl.AxisInitialize(-15, -15, 11, 11);
			gl.AxisX(-10, 10, 1, 1, "X label");
			gl.AxisY(-10, 10, 1, 1, "Y label");

			gl.SetAxisColor(Color.Brown);
			gl.AxisInitialize(-5, -1, 25, 11);
			gl.AxisXd(0, 20, 1, 5, "X AXIS LABEL");
			gl.AxisYl(0, 10, 1, 5, "Y AXIS LABEL");


			gl.SetAxisWidth(1);
			gl.SetAxisScaleMark(10);
			gl.AxisInitialize(-25, -25, 5, 5);
			gl.AxisXu(-20, 0, 1, 5, "X軸ラベル");
			gl.AxisYr(-20, 0, 1, 5, "Y軸ラベル", 30);

			gl.ResetAxisParm();
		}

		// ロータリーエンジン
		public void Plot_RotaryEngine(GraphLibrary gl)
		{
			gl.SetPenWidth(3);
			gl.SetPenColor(Color.Red);

			double R = 7.2;

			gl.PenUp();
			for (int i = 0; i <= 270 * 4; i++)
			{
				if (i != 0)
					gl.PenDown();
				double x = Math.Cos(i * deg2rad) + R * Math.Cos(i * deg2rad / 3);
				double y = Math.Sin(i * deg2rad) + R * Math.Sin(i * deg2rad / 3);
				gl.Move(x, y);
			}
		}

		// 三節四葉
		private void Plot_Rotary34(GraphLibrary gl)
		{
			gl.SetPenWidth(3);
			gl.SetPenColor(Color.Blue);

			gl.PenUp();
			for (int i = 0; i <= 360 * 4; i++)
			{
				if (i != 0)
					gl.PenDown();
				double x = Math.Cos(i * deg2rad) + 7 * Math.Cos(i * deg2rad / 4);
				double y = Math.Sin(i * deg2rad) + 7 * Math.Sin(i * deg2rad / 4);
				gl.Move(x, y);
			}
		}

		// リサージュ図形
		private void Plot_Lissajous(GraphLibrary gl)
		{
			gl.SetPenColor(Color.Black);
			gl.SetPenWidth(3);

			gl.PenUp();
			for (int i = 0; i <= 360; i++)
			{
				if (i != 0)
					gl.PenDown();
				double x = 4 * Math.Sin(5 * i * deg2rad + 135 * deg2rad);
				double y = 4 * Math.Sin(6 * i * deg2rad);
				gl.Move(x, y);
			}
		}

		// 文字列を出力
		private void Plot_Text(GraphLibrary gl)
		{
			gl.DrawString(0, 1, 0, 12, "Test message");
			gl.DrawString(0, 0, 4, "MS Pゴシック", 12, Color.Red, "string test msg");
			gl.DrawString(0 + gl.Device2User(1), -11 - gl.Device2User(1), 7,
				"MS Pゴシック", 24, Color.Black, "GraphLibrary Rev " + gl.Revision);
			gl.DrawString(0, -11, 7, "MS Pゴシック", 24, Color.Red, "GraphLibrary Rev " + gl.Revision);
			//gl.SetStringAlpha(100);
			//gl.DrawString(0.1, -10.9, 7, "MS Pゴシック", 24, Color.Red, "GraphLibrary Rev " + gl.Revision);
		}
		// ドットを出力
		private void Plot_Dot(GraphLibrary gl)
		{
			gl.SetPenColor(Color.Blue);

			gl.SetPenWidth(2);
			gl.DrawDot(2, 2);

			gl.SetPenWidth(3);
			gl.DrawDot(3, 3);

			gl.SetPenWidth(4);
			gl.DrawDot(4, 4);

			gl.SetPenColor(Color.Red);
			gl.SetPenWidth(5);
			gl.DrawDot(5, 5);

			gl.SetPenWidth(10);
			gl.DrawDot(6, 6);
		}

		// 円及び長方形の出力
		public void Plot_Line(GraphLibrary gl)
		{
			gl.ResetPenParm();
			gl.SetBrushAlpha(200);
			gl.SetPenColor(Color.Green);
			gl.SetPenWidth(3);
			gl.DrawLine(0, 0, -2, -2);

			gl.SetPenColor(Color.Red);
			gl.SetPenWidth(1);

			gl.DrawRectangle(0, 0, -2, -2);

			gl.SetPenColor(Color.Red);
			gl.DrawEllipse(-2, -2, 2, 2);
			gl.FillEllipse(9, -8, 7, -5);

			gl.DrawCircle(0, 0, 3);
			gl.SetPenColor(Color.Blue);
			gl.FillCircle(-7, -7, 0.5);

			gl.SetPenWidth(1);
			gl.SetPenColor(Color.Black);
			gl.DrawLine(-10, 6, -1, 6);

			gl.SetPenWidth(2);
			gl.SetPenColor(Color.Red);
			gl.SetPenStyle(DashStyle.Dot);
			gl.PenUp();
			gl.Move(-10, 5);
			gl.PenDown();
			gl.Move(-1, 5);

			gl.SetPenStyle(DashStyle.DashDot);
			gl.DrawLine(-10, 4, -1, 4);

			gl.SetPenStyle(DashStyle.DashDotDot);
			gl.DrawRectangle(-10, 3, -1, 2);

			gl.SetPenStyle(DashStyle.DashDotDot);
			gl.SetPenColor(Color.Blue);
			gl.DrawCircle(2, 0, 3);

			gl.SetPenStyle(DashStyle.Solid);
			double[,] array = new double[,] { { 6.0, 1.0 }, { 7.0, 1.0 }, { 8.0, 4.0 },
				{ 5.0, 5.0 }, { 9.0, 2.0 } };
			//gl.DrawPolygon(array);
			gl.FillPolygon(array, FillMode.Winding);
			//gl.DrawLines(array);
			//gl.DrawCurve(array, 0.5F);
			//gl.DrawClosedCurve(array, 0.5F);
			double[] point1 = new double[] { 6.0, 1.0 };
			double[] point2 = new double[] { 7.0, 1.0 };
			double[] point3 = new double[] { 7.0, 1.0 };
			double[] point4 = new double[] { 5.0, 5.0 };
			//gl.DrawBezier(point1, point2, point3, point4);
			double[,] array2 = new double[,] { { 6.0, 1.0 }, { 7.0, 1.0 }, { 8.0, 4.0 },
				{ 5.0, 5.0 } };
			gl.DrawBeziers(array2);

			gl.SetPenStyle(DashStyle.DashDotDot);
			gl.DrawArc(-9, -9, -7, -7, 0, 90);
			gl.DrawArc(-8, -8, 1, 180, 90);
			gl.DrawPie(-10, -10, -6, -6, 180, 20);
			gl.FillPie(-10, -10, -6, -6, 270, 20);

			gl.SetPenStyle(DashStyle.Dot);
			gl.DrawArc(-10, -9, -5, -5, 0, 90);
			gl.DrawPie(-10, -9, -5, -5, 90, 30);

			gl.SetPenColor(Color.Green);
			int alpha = 255;
			for (int i = 0; i < 360; i += 15)
			{
				gl.SetBrushAlpha(alpha);
				gl.FillPie(-3, 7, -7, 10, i, 15);
				alpha -= 10;
			}
		}

		private void Plot_DirectPath(GraphLibrary gl)
		{
			gl.ResetPenParm();
			//GraphicsPathオブジェクトの作成
			GraphicsPath myPath = new GraphicsPath();

			myPath.AddEllipse(gl.TransrateRect(-3, -2, 3, 2));

			//パス図形を描画する
			gl.DirectDrawPath(myPath);
		}

		private void Plot_FillPath(GraphLibrary gl)
		{
			Region rgn;
			Rectangle rect1, rect2;

			gl.SetBrushAlpha(255);

			//Regionで使用する2つの領域
			rect1 = new Rectangle(80, 0, 40, 40);
			rect2 = new Rectangle(100, 20, 40, 40);

			//GraphicsPathオブジェクトの作成
			GraphicsPath myPath1 = new GraphicsPath();
			GraphicsPath myPath2 = new GraphicsPath();

			myPath1.AddEllipse(rect1);
			myPath2.AddEllipse(rect2);

			//rect1を青で塗る
			gl.SetPenColor(Color.Blue);
			gl.DirectFillPath(myPath1);
			//rect2を緑で塗る
			gl.SetPenColor(Color.Green);
			gl.DirectFillPath(myPath2);
			//rect1でRegionを作成
			rgn = new Region(myPath1);
			//Union(和集合)によりrect2を追加
			rgn.Union(myPath2);
			//出来上がったRegionを黒で描画
			gl.SetPenColor(Color.Black);
			gl.DirectFillRegion(rgn);

			//rect1とrect2の位置を変更
			rect1.Y = rect2.Bottom + 10;
			rect2.Y = rect1.Y + 20;
			myPath1.Reset();
			myPath2.Reset();
			myPath1.AddEllipse(rect1);
			myPath2.AddEllipse(rect2);

			//rect1を青で塗る
			gl.SetPenColor(Color.Blue);
			gl.DirectFillPath(myPath1);
			//rect2を緑で塗る
			gl.SetPenColor(Color.Green);
			gl.DirectFillPath(myPath2);
			//rect1でRegionを作成
			rgn = new Region(myPath1);
			//Intersect(交差部分)によりrect2を追加
			rgn.Intersect(myPath2);
			//出来上がったRegionを黒で描画
			gl.SetPenColor(Color.Black);
			gl.DirectFillRegion(rgn);

			//rect1とrect2の位置を変更
			rect1.Y = rect2.Bottom + 10;
			rect2.Y = rect1.Y + 20;
			myPath1.Reset();
			myPath2.Reset();
			myPath1.AddEllipse(rect1);
			myPath2.AddEllipse(rect2);

			//rect1を青で塗る
			gl.SetPenColor(Color.Blue);
			gl.DirectFillPath(myPath1);
			//rect2を緑で塗る
			gl.SetPenColor(Color.Green);
			gl.DirectFillPath(myPath2);
			//rect1でRegionを作成
			rgn = new Region(myPath1);
			//Exclude(交差しない内部の部分)によりrect2を追加
			rgn.Exclude(myPath2);
			//出来上がったRegionを黒で描画
			gl.SetPenColor(Color.Black);
			gl.DirectFillRegion(rgn);

			//rect1とrect2の位置を変更
			rect1.Y = rect2.Bottom + 10;
			rect2.Y = rect1.Y + 20;
			myPath1.Reset();
			myPath2.Reset();
			myPath1.AddEllipse(rect1);
			myPath2.AddEllipse(rect2);

			//rect1を青で塗る
			gl.SetPenColor(Color.Blue);
			gl.DirectFillPath(myPath1);
			//rect2を緑で塗る
			gl.SetPenColor(Color.Green);
			gl.DirectFillPath(myPath2);
			//rect1でRegionを作成
			rgn = new Region(myPath1);
			//Xor(交差部分を差し引いた和集合)によりrect2を追加
			rgn.Xor(myPath2);
			//出来上がったRegionを黒で描画
			gl.SetPenColor(Color.Black);
			gl.DirectFillRegion(rgn);
		}

		private void Plot_Path(GraphLibrary gl)
		{
			gl.ResetPenParm();
			//GraphicsPathオブジェクトの作成
			GraphicsPath myPath = new GraphicsPath();

			//新しい図形を開始する
			myPath.StartFigure();
			//直線を2本追加する
			myPath.AddLine(0, 0, 50, 50);
			myPath.AddLine(100, 0, 150, 50);
			//図形を閉じる
			myPath.CloseFigure();

			//新しい図形を開始する
			myPath.StartFigure();
			//直線を2本追加する
			myPath.AddLine(0, 60, 50, 110);
			myPath.AddLine(100, 60, 150, 110);

			//新しい図形を開始する
			myPath.StartFigure();
			//直線を追加する
			myPath.AddLine(100, 120, 150, 170);
			//新しい図形を開始する
			myPath.StartFigure();
			//直線を追加する
			myPath.AddLine(0, 120, 50, 170);

			//四角を2つ追加する
			myPath.AddRectangle(new Rectangle(160, 10, 60, 80));
			myPath.AddRectangle(new Rectangle(160, 100, 60, 60));

			//パス図形を描画する
			gl.DirectDrawPath(myPath);
		}

	}
}
